==> open-xchange-oauth_7.10.1.orig.tar.bz2: open-xchange-oauth-7.10.1/com.openexchange.gmail.send/src/com/openexchange/gmail/send/oauth/GmailSendOAuthAccountAssociation.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.gmail.send.oauth;

import com.openexchange.exception.OXException;
import com.openexchange.gmail.send.GmailSendProvider;
import com.openexchange.mail.transport.MailTransport;
import com.openexchange.mailaccount.TransportAccount;
import com.openexchange.oauth.association.OAuthAccountAssociation;
import com.openexchange.oauth.association.Status;
import com.openexchange.oauth.association.Type;
import com.openexchange.session.Session;


/**
 * {@link GmailSendOAuthAccountAssociation}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.3
 */
public class GmailSendOAuthAccountAssociation implements OAuthAccountAssociation {

    private final int accountId;
    private final TransportAccount account;
    private final int userId;
    private final int contextId;

    /**
     * Initializes a new {@link GmailSendOAuthAccountAssociation}.
     *
     * @param accountId The identifier of the OAuth account
     * @param account The associated transport account
     * @param userId The user identifier
     * @param contextId The context identifier
     */
    public GmailSendOAuthAccountAssociation(int accountId, TransportAccount account, int userId, int contextId) {
        super();
        this.accountId = accountId;
        this.account = account;
        this.userId = userId;
        this.contextId = contextId;
    }

    @Override
    public int getOAuthAccountId() {
        return accountId;
    }

    @Override
    public int getUserId() {
        return userId;
    }

    @Override
    public int getContextId() {
        return contextId;
    }

    @Override
    public String getServiceId() {
        return GmailSendProvider.PROTOCOL_GMAIL_SEND.getName();
    }

    @Override
    public String getId() {
        return Integer.toString(account.getId());
    }

    @Override
    public String getDisplayName() {
        return account.getName();
    }

    @Override
    public Status getStatus(Session session) throws OXException {
        try {
            MailTransport transport = MailTransport.getInstance(session, account.getId());
            transport.ping();
            return Status.OK;
        } catch (OXException e) {
            return Status.RECREATION_NEEDED;
        }
    }

    @Override
    public Type getType() {
        return Type.MAIL;
    }

}

==> open-xchange-oauth_7.10.3.orig.tar.bz2: open-xchange-oauth-7.10.3/com.openexchange.gmail.send/src/com/openexchange/gmail/send/oauth/GmailSendOAuthAccountAssociation.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.gmail.send.oauth;

import java.util.Collections;
import java.util.List;
import com.openexchange.exception.OXException;
import com.openexchange.gmail.send.GmailSendProvider;
import com.openexchange.mail.dataobjects.MailFolder;
import com.openexchange.mail.transport.MailTransport;
import com.openexchange.mail.utils.MailFolderUtility;
import com.openexchange.mailaccount.TransportAccount;
import com.openexchange.oauth.association.Module;
import com.openexchange.oauth.association.OAuthAccountAssociation;
import com.openexchange.oauth.association.Status;
import com.openexchange.oauth.google.GoogleOAuthScope;
import com.openexchange.oauth.scope.OAuthScope;
import com.openexchange.session.Session;


/**
 * {@link GmailSendOAuthAccountAssociation}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.3
 */
public class GmailSendOAuthAccountAssociation implements OAuthAccountAssociation {

    private final int accountId;
    private final TransportAccount account;
    private final int userId;
    private final int contextId;

    /**
     * Initializes a new {@link GmailSendOAuthAccountAssociation}.
     *
     * @param accountId The identifier of the OAuth account
     * @param account The associated transport account
     * @param userId The user identifier
     * @param contextId The context identifier
     */
    public GmailSendOAuthAccountAssociation(int accountId, TransportAccount account, int userId, int contextId) {
        super();
        this.accountId = accountId;
        this.account = account;
        this.userId = userId;
        this.contextId = contextId;
    }

    @Override
    public int getOAuthAccountId() {
        return accountId;
    }

    @Override
    public int getUserId() {
        return userId;
    }

    @Override
    public int getContextId() {
        return contextId;
    }

    @Override
    public String getServiceId() {
        return GmailSendProvider.PROTOCOL_GMAIL_SEND.getName();
    }

    @Override
    public String getId() {
        return Integer.toString(account.getId());
    }

    @Override
    public String getDisplayName() {
        return account.getName();
    }

    @Override
    public String getModule() {
        return Module.MAIL.getModuleName();
    }

    @Override
    public String getFolder() {
        return MailFolderUtility.prepareFullname(account.getId(), MailFolder.DEFAULT_FOLDER_ID);
    }

    @Override
    public Status getStatus(Session session) throws OXException {
        try {
            MailTransport transport = MailTransport.getInstance(session, account.getId());
            transport.ping();
            return Status.OK;
        } catch (OXException e) {
            return Status.RECREATION_NEEDED;
        }
    }

    @Override
    public List<OAuthScope> getScopes() {
        return Collections.singletonList(GoogleOAuthScope.mail);
    }

}
